@@ -1,7 +1,7 @@
 #!/bin/sh
-[ -f /usr/share/acpi-support/key-constants ] || exit 0
+test -f /usr/share/acpi-support/key-constants || exit 0
+
 . /usr/share/acpi-support/key-constants
-. /usr/share/acpi-support/device-funcs
 
 DeviceConfig
 
